@@ -20,10 +20,17 @@ class Avatar(o.Avatar):
             "favoriteId": self.id, "tags": ["avatars1"]})
 
         f = Favorite(self.client, resp["data"])
-        await f.cacheTask
+        if self.client.caching: await f.cacheTask
 
         return f
 
+    async def select(self):
+        '''
+        Selects this avatar to be used/worn
+        '''
+
+        await self.client.api.call("/avatars/{}/select".format(self.id), "PUT")
+
 ## User
 
 class LimitedUser(o.LimitedUser):
@@ -122,8 +129,8 @@ class CurrentUser(o.CurrentUser, User):
         for favorite in resp["data"]:
             f.append(Favorite(self.client, favorite))
 
-        for fav in f:
-            await fav.cacheTask
+        if self.client.caching:
+            for fav in f: await fav.cacheTask
 
         return f
 
@@ -161,7 +168,7 @@ class CurrentUser(o.CurrentUser, User):
         else: self.homeLocation = None
 
         # Wait for all cacheTasks
-        if not self.homeLocation == None:
+        if not self.homeLocation == None and self.client.caching:
             await self.homeLocation.cacheTask
 
 ## World
