@@ -272,11 +272,11 @@ class Client:
 
         self.api.set_auth(auth)
         self.api.session.cookies.set("auth", resp["response"].cookies["auth"])
-
+        
         self.me = objects.CurrentUser(self, resp["data"])
         self.loggedIn = True
 
-    def login2fa(self, username, password, code=None, verify=False, otp=False):
+    def login2fa(self, username, password, code=None, verify=False):
         '''
         Used to initialize client for use (for accounts with 2FactorAuth)
 
@@ -292,9 +292,6 @@ class Client:
             verify, boolean
             Whether to verify 2FactorAuth code, or leave for later
 
-            otp, boolean
-            If verify is true, to verify with otp (recovery) or totp (2FactorAuth)
-
         This will ignore the RequiresTwoFactorAuthError exception, so be careful!
         If kwarg verify is False, Client.verify2fa() must be called after
         '''
@@ -309,30 +306,31 @@ class Client:
         try:
             resp = self.api.call("/auth/user", headers={"Authorization": "Basic "+auth}, no_auth=True, verify=False)
             raise_for_status(resp)
+
+            self.api.set_auth(auth)
+            self.api.session.cookies.set("auth", resp["response"].cookies["auth"])
+
+            self.me = objects.CurrentUser(self, resp["data"])
+            self.loggedIn = True
         except RequiresTwoFactorAuthError:
             self.api.set_auth(auth)
             self.api.session.cookies.set("auth", resp["response"].cookies["auth"]) # Auth cookieeee
             if verify:
                 self.needsVerification = True
-                self.verify2fa(code, otp)
+                self.verify2fa(code)
             else: self.needsVerification = True
 
-    def verify2fa(self, code, otp=False):
+    def verify2fa(self, code):
         '''
         Used to finish initializing client for use after Client.login2fa()
 
             code, string
             2FactorAuth code
-
-            otp, boolean
-            To verify with otp (recovery) or totp (2FactorAuth)
         '''
 
         if self.loggedIn: raise AlreadyLoggedInError("Client is already logged in")
 
-        if otp: self.api.call("/auth/twofactorauth/otp/verify", "POST", json={"code": code})
-        else: self.api.call("/auth/twofactorauth/totp/verify", "POST", json={"code": code})
-
+        resp = self.api.call("/auth/twofactorauth/totp/verify", "POST", json={"code": code})
         resp = self.api.call("/auth/user")
 
         self.me = objects.CurrentUser(self, resp["data"])
@@ -610,7 +608,7 @@ class AClient(Client):
 
         await self.me.cacheTask
 
-    async def login2fa(self, username, password, code=None, verify=False, otp=False):
+    async def login2fa(self, username, password, code=None, verify=False):
         '''
         Used to initialize client for use (for accounts with 2FactorAuth)
 
@@ -626,9 +624,6 @@ class AClient(Client):
             verify, boolean
             Whether to verify 2FactorAuth code, or leave for later
 
-            otp, boolean
-            If verify is true, to verify with otp (recovery) or totp (2FactorAuth)
-
         This will ignore the RequiresTwoFactorAuthError exception, so be careful!
         If kwarg verify is False, AClient.verify2fa() must be called after
         '''
@@ -643,39 +638,42 @@ class AClient(Client):
         try:
             resp = await self.api.call("/auth/user", headers={"Authorization": "Basic "+auth}, no_auth=True, verify=False)
             raise_for_status(resp)
+
+            self.api.openSession(auth)
+            self.api.session.cookie_jar.update_cookies([["auth", resp["response"].headers["Set-Cookie"].split(';')[0].split("=")[1]]])
+
+            self.me = aobjects.CurrentUser(self, resp["data"])
+            self.loggedIn = True
+
+            await self.me.cacheTask
         except RequiresTwoFactorAuthError:
             self.api.openSession(auth)
             self.api.session.cookie_jar.update_cookies([["auth", resp["response"].headers["Set-Cookie"].split(';')[0].split("=")[1]]])
 
             if verify:
                 self.needsVerification = True
-                await self.verify2fa(code, otp)
+                await self.verify2fa(code)
             else:
                 self.needsVerification = True
 
-    async def verify2fa(self, code, otp=False):
+    async def verify2fa(self, code):
         '''
         Used to finish initializing client for use after AClient.login2fa()
 
             code, string
             2FactorAuth code
-
-            otp, boolean
-            To verify with otp (recovery) or totp (2FactorAuth)
         '''
 
         if self.loggedIn: raise AlreadyLoggedInError("Client is already logged in")
 
-        if otp: await self.api.call("/auth/twofactorauth/otp/verify", "POST", json={"code": code})
-        else: await self.api.call("/auth/twofactorauth/totp/verify", "POST", json={"code": code})
-
+        await self.api.call("/auth/twofactorauth/totp/verify", "POST", json={"code": code})
         resp = await self.api.call("/auth/user")
 
         self.me = aobjects.CurrentUser(self, resp["data"])
         self.loggedIn = True
         self.needsVerification = False
 
-        await self.me.cacheTask
+        if self.caching: await self.me.cacheTask
 
     def __init__(self, verify=True, caching=True):
         super().__init__()
